[svn] GnuPG - r4616 - in branches/STABLE-BRANCH-1-4: . doc g10

svn author wk cvs at cvs.gnupg.org
Mon Nov 12 16:52:11 CET 2007


Author: wk
Date: 2007-11-12 16:52:01 +0100 (Mon, 12 Nov 2007)
New Revision: 4616

Modified:
   branches/STABLE-BRANCH-1-4/AUTHORS
   branches/STABLE-BRANCH-1-4/doc/faq.raw
   branches/STABLE-BRANCH-1-4/g10/ChangeLog
   branches/STABLE-BRANCH-1-4/g10/status.c
Log:
 * status.c (do_get_from_fd, do_shm_get): s/bool/getbool/ to
   overcome problems with Mac OS 10.5 which seems to include
   stdbool.h silently.
 


Modified: branches/STABLE-BRANCH-1-4/AUTHORS
===================================================================
--- branches/STABLE-BRANCH-1-4/AUTHORS	2007-10-31 13:09:16 UTC (rev 4615)
+++ branches/STABLE-BRANCH-1-4/AUTHORS	2007-11-12 15:52:01 UTC (rev 4616)
@@ -2,6 +2,7 @@
 Maintainer:  Werner Koch <wk at gnupg.org>
 Bug reports: <bug-gnupg at gnu.org>
 Security related bug reports: <security at gnupg.org>
+License: GPLv3+
 
 
 Authors

Modified: branches/STABLE-BRANCH-1-4/doc/faq.raw
===================================================================
--- branches/STABLE-BRANCH-1-4/doc/faq.raw	2007-10-31 13:09:16 UTC (rev 4615)
+++ branches/STABLE-BRANCH-1-4/doc/faq.raw	2007-11-12 15:52:01 UTC (rev 4616)
@@ -1338,5 +1338,6 @@
 [H hr]
 
 Copyright (C) 2000, 2001, 2002, 2003 Free Software Foundation, Inc.,
+
 Verbatim copying and distribution of this entire article is permitted in
 any medium, provided this notice is preserved.

Modified: branches/STABLE-BRANCH-1-4/g10/ChangeLog
===================================================================
--- branches/STABLE-BRANCH-1-4/g10/ChangeLog	2007-10-31 13:09:16 UTC (rev 4615)
+++ branches/STABLE-BRANCH-1-4/g10/ChangeLog	2007-11-12 15:52:01 UTC (rev 4616)
@@ -1,3 +1,9 @@
+2007-11-12  Werner Koch  <wk at g10code.com>
+
+	* status.c (do_get_from_fd, do_shm_get): s/bool/getbool/ to
+	overcome problems with Mac OS 10.5 which seems to include
+	stdbool.h silently.
+
 2007-10-27  David Shaw  <dshaw at jabberwocky.com>
 
 	* parse-packet.c (parse_onepass_sig): Sigclass is hex, so include

Modified: branches/STABLE-BRANCH-1-4/g10/status.c
===================================================================
--- branches/STABLE-BRANCH-1-4/g10/status.c	2007-10-31 13:09:16 UTC (rev 4615)
+++ branches/STABLE-BRANCH-1-4/g10/status.c	2007-11-12 15:52:01 UTC (rev 4616)
@@ -468,10 +468,10 @@
 
 /****************
  * Request a string from client
  * If bool, returns static string on true (do not free) or NULL for false
  */
 static char *
-do_shm_get( const char *keyword, int hidden, int bool )
+do_shm_get( const char *keyword, int hidden, int getbool )
 {
     size_t n;
     byte *p;
@@ -485,7 +485,7 @@
     shm_area[2] = 1;  /* indicate that we are waiting on a reply */
     shm_area[3] = 0;  /* clear data available flag */
 
-    write_status_text( bool? STATUS_SHM_GET_BOOL :
+    write_status_text( getbool? STATUS_SHM_GET_BOOL :
 		       hidden? STATUS_SHM_GET_HIDDEN : STATUS_SHM_GET, keyword );
 
     do {
@@ -500,7 +500,7 @@
     if( n+32+2+1 > 4095 )
 	log_fatal("client returns too large data (%u bytes)\n", (unsigned)n );
 
-    if( bool )
+    if( getbool )
 	return p[0]? "" : NULL;
 
     string = hidden? xmalloc_secure( n+1 ) : xmalloc( n+1 );
@@ -543,10 +543,10 @@
 
 /****************
  * Request a string from the client over the command-fd
  * If bool, returns static string on true (do not free) or NULL for false
  */
 static char *
-do_get_from_fd( const char *keyword, int hidden, int bool )
+do_get_from_fd( const char *keyword, int hidden, int getbool )
 {
     int i, len;
     char *string;
@@ -554,7 +554,7 @@
     if(statusfp!=stdout)
       fflush(stdout);
 
-    write_status_text( bool? STATUS_GET_BOOL :
+    write_status_text( getbool? STATUS_GET_BOOL :
 		       hidden? STATUS_GET_HIDDEN : STATUS_GET_LINE, keyword );
 
     for( string = NULL, i = len = 200; ; i++ ) {
@@ -581,7 +581,7 @@
 
     write_status( STATUS_GOT_IT );
 
-    if( bool )	 /* Fixme: is this correct??? */
+    if( getbool )	 /* Fixme: is this correct??? */
 	return (string[0] == 'Y' || string[0] == 'y') ? "" : NULL;
 
     return string;
@@ -468,10 +468,10 @@
 /****************
  * Request a string from client
- * If bool, returns static string on true (do not free) or NULL for false
+ * If GETBOOL, returns static string on true (do not free) or NULL for false
  */
 static char *
@@ -543,10 +543,10 @@
 /****************
  * Request a string from the client over the command-fd
- * If bool, returns static string on true (do not free) or NULL for false
+ * If getbool, returns static string on true (do not free) or NULL for false
  */
 static char *




More information about the Gnupg-commits mailing list